package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.menu.domain.MenuEvaluaDetail;
import com.bonus.canteen.core.menu.service.IMenuEvaluaDetailService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 订单评价菜品Controller
 * 
 * @author xsheng
 * @date 2025-04-20
 */
@Api(tags = "订单评价菜品接口")
@RestController
@RequestMapping("/menu_evalua_detail")
public class MenuEvaluaDetailController extends BaseController {
    @Autowired
    private IMenuEvaluaDetailService menuEvaluaDetailService;

    /**
     * 查询订单评价菜品列表
     */
    @ApiOperation(value = "查询订单评价菜品列表")
    //@RequiresPermissions("menu:detail:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuEvaluaDetail menuEvaluaDetail) {
        startPage();
        List<MenuEvaluaDetail> list = menuEvaluaDetailService.selectMenuEvaluaDetailList(menuEvaluaDetail);
        return getDataTable(list);
    }

    /**
     * 导出订单评价菜品列表
     */
    @ApiOperation(value = "导出订单评价菜品列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:export")
    @SysLog(title = "订单评价菜品", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出订单评价菜品")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuEvaluaDetail menuEvaluaDetail) {
        List<MenuEvaluaDetail> list = menuEvaluaDetailService.selectMenuEvaluaDetailList(menuEvaluaDetail);
        ExcelUtil<MenuEvaluaDetail> util = new ExcelUtil<MenuEvaluaDetail>(MenuEvaluaDetail.class);
        util.exportExcel(response, list, "订单评价菜品数据");
    }

    /**
     * 获取订单评价菜品详细信息
     */
    @ApiOperation(value = "获取订单评价菜品详细信息")
    //@RequiresPermissions("menu:detail:query")
    @GetMapping(value = "/{detailId}")
    public AjaxResult getInfo(@PathVariable("detailId") Long detailId) {
        return success(menuEvaluaDetailService.selectMenuEvaluaDetailById(detailId));
    }

    /**
     * 新增订单评价菜品
     */
    @ApiOperation(value = "新增订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:add")
    @SysLog(title = "订单评价菜品", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增订单评价菜品")
    @PostMapping
    public AjaxResult add(@RequestBody MenuEvaluaDetail menuEvaluaDetail) {
        try {
            return toAjax(menuEvaluaDetailService.insertMenuEvaluaDetail(menuEvaluaDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改订单评价菜品
     */
    @ApiOperation(value = "修改订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:edit")
    @SysLog(title = "订单评价菜品", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改订单评价菜品")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuEvaluaDetail menuEvaluaDetail) {
        try {
            return toAjax(menuEvaluaDetailService.updateMenuEvaluaDetail(menuEvaluaDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除订单评价菜品
     */
    @ApiOperation(value = "删除订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:remove")
    @SysLog(title = "订单评价菜品", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除订单评价菜品")
	@PostMapping("/del/{detailIds}")
    public AjaxResult remove(@PathVariable Long[] detailIds) {
        return toAjax(menuEvaluaDetailService.deleteMenuEvaluaDetailByIds(detailIds));
    }
}
